@@ -44,8 +44,8 @@ Boston, MA 02111-1307, USA.  */
 static void *xmalloc (size_t);
 static void *xrealloc (void *, size_t);
 static void skip_to_lf (FILE *stream);
-static void fatal (CONST char *s1, CONST char *s2);
-static void error (CONST char *s1, CONST char *s2);
+static void fatal (const char *s1, const char *s2);
+static void error (const char *s1, const char *s2);
 
 int
 main (int argc, char *argv[])
@@ -139,14 +139,14 @@ xrealloc (void *ptr, size_t size)
 /* Print error message and exit.  */
 
 static void
-fatal (CONST char *s1, CONST char *s2)
+fatal (const char *s1, const char *s2)
 {
   error (s1, s2);
   exit (1);
 }
 
 static void
-error (CONST char *s1, CONST char *s2)
+error (const char *s1, const char *s2)
 {
   fprintf (stderr, "cvtmail: ");
   fprintf (stderr, s1, s2);
