@@ -57,110 +57,141 @@ emacs_Xt_mapping_action (Widget w, XEvent* event);
 #undef XtOffset
 #define XtOffset(p_type,field) \
 	((Cardinal) (((char *) (&(((p_type)0)->field))) - ((char *)0)))
-#define offset(field) XtOffset(EmacsFrame, emacs_frame.field)
+#define offset(field) XtOffset (EmacsFrame, emacs_frame.field)
 
 static XtResource resources[] = {
-  {XtNgeometry, XtCGeometry, XtRString, sizeof(String),
-     offset (geometry), XtRString, (XtPointer) 0},
-  {XtNiconic, XtCIconic, XtRBoolean, sizeof(Boolean),
-     offset (iconic), XtRImmediate, (XtPointer) False},
+  { XtNgeometry, XtCGeometry,
+    XtRString, sizeof (String),
+    offset (geometry), XtRString, (XtPointer) 0 },
+  { XtNiconic, XtCIconic,
+    XtRBoolean, sizeof (Boolean),
+    offset (iconic), XtRImmediate, (XtPointer) False },
 
-  {XtNemacsFrame, XtCEmacsFrame, XtRPointer, sizeof (XtPointer),
-     offset (frame), XtRImmediate, 0},
-  {XtNmenubar, XtCMenubar, XtRBoolean, sizeof (Boolean),
-     offset (menubar_p), XtRImmediate, (XtPointer) True},
-  {XtNinitiallyUnmapped, XtCInitiallyUnmapped, XtRBoolean, sizeof (Boolean),
-     offset (initially_unmapped), XtRImmediate, (XtPointer) False},
-  {XtNminibuffer, XtCMinibuffer, XtRBoolean, sizeof (Boolean),
-     offset (minibuffer), XtRImmediate, (XtPointer) True},
-  {XtNunsplittable, XtCUnsplittable, XtRBoolean, sizeof (Boolean),
-     offset (unsplittable), XtRImmediate, (XtPointer) False},
-  {XtNinternalBorderWidth, XtCInternalBorderWidth, XtRInt, sizeof (int),
-     offset (internal_border_width), XtRImmediate, (XtPointer)4},
+  { XtNemacsFrame, XtCEmacsFrame,
+    XtRPointer, sizeof (XtPointer),
+    offset (frame), XtRImmediate, 0 },
+  { XtNmenubar, XtCMenubar,
+    XtRBoolean, sizeof (Boolean),
+    offset (menubar_p), XtRImmediate, (XtPointer) True },
+  { XtNinitiallyUnmapped, XtCInitiallyUnmapped,
+    XtRBoolean, sizeof (Boolean),
+    offset (initially_unmapped), XtRImmediate, (XtPointer) False },
+  { XtNminibuffer, XtCMinibuffer,
+    XtRBoolean, sizeof (Boolean),
+    offset (minibuffer), XtRImmediate, (XtPointer) True },
+  { XtNunsplittable, XtCUnsplittable,
+    XtRBoolean, sizeof (Boolean),
+    offset (unsplittable), XtRImmediate, (XtPointer) False },
+  { XtNinternalBorderWidth, XtCInternalBorderWidth,
+    XtRInt, sizeof (int),
+    offset (internal_border_width), XtRImmediate, (XtPointer)4 },
 #ifdef HAVE_SCROLLBARS
-  {XtNscrollBarWidth, XtCScrollBarWidth, XtRInt, sizeof (int),
-     offset (scrollbar_width), XtRImmediate, (XtPointer)-1},
-  {XtNscrollBarHeight, XtCScrollBarHeight, XtRInt, sizeof (int),
-     offset (scrollbar_height), XtRImmediate, (XtPointer)-1},
-  {XtNscrollBarPlacement, XtCScrollBarPlacement, XtRScrollBarPlacement,
-      sizeof(unsigned char), offset(scrollbar_placement), XtRImmediate,
+  { XtNscrollBarWidth, XtCScrollBarWidth,
+    XtRInt, sizeof (int),
+    offset (scrollbar_width), XtRImmediate, (XtPointer)-1 },
+  { XtNscrollBarHeight, XtCScrollBarHeight,
+    XtRInt, sizeof (int),
+    offset (scrollbar_height), XtRImmediate, (XtPointer)-1 },
+  { XtNscrollBarPlacement, XtCScrollBarPlacement,
+    XtRScrollBarPlacement, sizeof (unsigned char),
+    offset (scrollbar_placement), XtRImmediate,
 #if defined (LWLIB_SCROLLBARS_MOTIF) || defined (LWLIB_SCROLLBARS_LUCID) || \
     defined (LWLIB_SCROLLBARS_ATHENA3D)
-      (XtPointer) XtBOTTOM_RIGHT
+    (XtPointer) XtBOTTOM_RIGHT
 #else
-      (XtPointer) XtBOTTOM_LEFT
+    (XtPointer) XtBOTTOM_LEFT
 #endif
   },
 #endif /* HAVE_SCROLLBARS */
+
 #ifdef HAVE_TOOLBARS
-  {XtNtopToolBarHeight, XtCTopToolBarHeight, XtRInt, sizeof (int),
-     offset (top_toolbar_height), XtRImmediate, (XtPointer)-1},
-  {XtNbottomToolBarHeight, XtCBottomToolBarHeight, XtRInt, sizeof (int),
-     offset (bottom_toolbar_height), XtRImmediate, (XtPointer)-1},
-  {XtNleftToolBarWidth, XtCLeftToolBarWidth, XtRInt, sizeof (int),
-     offset (left_toolbar_width), XtRImmediate, (XtPointer)-1},
-  {XtNrightToolBarWidth, XtCRightToolBarWidth, XtRInt, sizeof (int),
-     offset (right_toolbar_width), XtRImmediate, (XtPointer)-1},
-  {XtNtopToolBarBorderWidth, XtCTopToolBarBorderWidth, XtRInt,
-     sizeof (int),
-     offset (top_toolbar_border_width), XtRImmediate, (XtPointer)-1},
-  {XtNbottomToolBarBorderWidth, XtCBottomToolBarBorderWidth, XtRInt,
-     sizeof (int),
-     offset (bottom_toolbar_border_width), XtRImmediate, (XtPointer)-1},
-  {XtNleftToolBarBorderWidth, XtCLeftToolBarBorderWidth, XtRInt,
-     sizeof (int),
-     offset (left_toolbar_border_width), XtRImmediate, (XtPointer)-1},
-  {XtNrightToolBarBorderWidth, XtCRightToolBarBorderWidth, XtRInt,
-     sizeof (int),
-     offset (right_toolbar_border_width), XtRImmediate, (XtPointer)-1},
-  {XtNtopToolBarShadowColor, XtCTopToolBarShadowColor, XtRPixel, sizeof(Pixel),
-     offset(top_toolbar_shadow_pixel), XtRString, (XtPointer) "#000000"},
-  {XtNbottomToolBarShadowColor, XtCBottomToolBarShadowColor, XtRPixel,
-     sizeof(Pixel), offset(bottom_toolbar_shadow_pixel), XtRString, (XtPointer) "#000000"},
-  {XtNbackgroundToolBarColor, XtCBackgroundToolBarColor, XtRPixel,
-     sizeof(Pixel), offset(background_toolbar_pixel), XtRImmediate,
-     (XtPointer)-1},
-  {XtNforegroundToolBarColor, XtCForegroundToolBarColor, XtRPixel,
-     sizeof(Pixel), offset(foreground_toolbar_pixel), XtRImmediate,
-     (XtPointer)-1},
-  {XtNtopToolBarShadowPixmap, XtCTopToolBarShadowPixmap, XtRPixmap,
-     sizeof (Pixmap), offset(top_toolbar_shadow_pixmap), XtRImmediate,
-     (XtPointer)None},
-  {XtNbottomToolBarShadowPixmap, XtCBottomToolBarShadowPixmap, XtRPixmap,
-     sizeof (Pixmap), offset(bottom_toolbar_shadow_pixmap), XtRImmediate,
-     (XtPointer)None},
-  {XtNtoolBarShadowThickness, XtCToolBarShadowThickness, XtRDimension,
-     sizeof (Dimension), offset (toolbar_shadow_thickness), XtRImmediate,
-     (XtPointer)2},
+  { XtNtopToolBarHeight, XtCTopToolBarHeight,
+    XtRInt, sizeof (int),
+    offset (top_toolbar_height), XtRImmediate, (XtPointer)-1 },
+  { XtNbottomToolBarHeight, XtCBottomToolBarHeight,
+    XtRInt, sizeof (int),
+    offset (bottom_toolbar_height), XtRImmediate, (XtPointer)-1 },
+  { XtNleftToolBarWidth, XtCLeftToolBarWidth,
+    XtRInt, sizeof (int),
+    offset (left_toolbar_width), XtRImmediate, (XtPointer)-1 },
+  { XtNrightToolBarWidth, XtCRightToolBarWidth,
+    XtRInt, sizeof (int),
+    offset (right_toolbar_width), XtRImmediate, (XtPointer)-1 },
+  { XtNtopToolBarBorderWidth, XtCTopToolBarBorderWidth,
+    XtRInt, sizeof (int),
+    offset (top_toolbar_border_width), XtRImmediate, (XtPointer)-1 },
+  { XtNbottomToolBarBorderWidth, XtCBottomToolBarBorderWidth,
+    XtRInt, sizeof (int),
+    offset (bottom_toolbar_border_width), XtRImmediate, (XtPointer)-1 },
+  { XtNleftToolBarBorderWidth, XtCLeftToolBarBorderWidth,
+    XtRInt, sizeof (int),
+    offset (left_toolbar_border_width), XtRImmediate, (XtPointer)-1 },
+  { XtNrightToolBarBorderWidth, XtCRightToolBarBorderWidth,
+    XtRInt, sizeof (int),
+    offset (right_toolbar_border_width), XtRImmediate, (XtPointer)-1 },
+  { XtNtopToolBarShadowColor, XtCTopToolBarShadowColor,
+    XtRPixel, sizeof (Pixel),
+    offset(top_toolbar_shadow_pixel), XtRString, (XtPointer) "#000000" },
+  { XtNbottomToolBarShadowColor, XtCBottomToolBarShadowColor,
+    XtRPixel, sizeof (Pixel),
+    offset (bottom_toolbar_shadow_pixel), XtRString, (XtPointer) "#000000" },
+  { XtNbackgroundToolBarColor, XtCBackgroundToolBarColor,
+    XtRPixel, sizeof (Pixel),
+    offset (background_toolbar_pixel), XtRImmediate, (XtPointer)-1 },
+  { XtNforegroundToolBarColor, XtCForegroundToolBarColor,
+    XtRPixel, sizeof (Pixel),
+    offset (foreground_toolbar_pixel), XtRImmediate, (XtPointer)-1 },
+  { XtNtopToolBarShadowPixmap, XtCTopToolBarShadowPixmap,
+    XtRPixmap, sizeof (Pixmap),
+    offset (top_toolbar_shadow_pixmap), XtRImmediate, (XtPointer)None },
+  { XtNbottomToolBarShadowPixmap, XtCBottomToolBarShadowPixmap,
+    XtRPixmap, sizeof (Pixmap),
+    offset (bottom_toolbar_shadow_pixmap), XtRImmediate, (XtPointer)None },
+  { XtNtoolBarShadowThickness, XtCToolBarShadowThickness,
+    XtRDimension, sizeof (Dimension),
+    offset (toolbar_shadow_thickness), XtRImmediate, (XtPointer)2 },
 #endif /* HAVE_TOOLBARS */
-  {XtNinterline, XtCInterline, XtRInt, sizeof (int),
-     offset (interline), XtRImmediate, (XtPointer)0},
+
+  { XtNinterline, XtCInterline,
+    XtRInt, sizeof (int),
+    offset (interline), XtRImmediate, (XtPointer)0 },
   {
 #ifdef I18N4
-    XtNfontSet, XtCFontSet, XtRFontSet,    sizeof(XFontSet),
+    XtNfontSet, XtCFontSet,
+    XtRFontSet, sizeof (XFontSet),
 #else
-    XtNfont,    XtCFont,    XtRFontStruct, sizeof(XFontStruct *),
+    XtNfont, XtCFont,
+    XtRFontStruct, sizeof (XFontStruct *),
 #endif
     offset(font), XtRImmediate, (XtPointer)0
   },
-  {XtNforeground, XtCForeground, XtRPixel, sizeof(Pixel),
-     offset(foreground_pixel), XtRString, (XtPointer) "Black"},
-  {XtNbackground, XtCBackground, XtRPixel, sizeof(Pixel),
-     offset(background_pixel), XtRString, (XtPointer) "Gray80"},
-  {XtNcursorColor, XtCForeground, XtRPixel, sizeof(Pixel),
-     offset(cursor_color), XtRString, (XtPointer) "XtDefaultForeground"},
-  {XtNbarCursor, XtCBarCursor, XtRBoolean, sizeof (Boolean),
-     offset (bar_cursor), XtRImmediate, (XtPointer)0},
-  {XtNvisualBell, XtCVisualBell, XtRBoolean, sizeof (Boolean),
-     offset (visual_bell), XtRImmediate, (XtPointer)0},
-  {XtNbellVolume, XtCBellVolume, XtRInt, sizeof (int),
-     offset (bell_volume), XtRImmediate, (XtPointer)0},
-  {XtNuseBackingStore, XtCUseBackingStore, XtRBoolean, sizeof (Boolean),
-     offset (use_backing_store), XtRImmediate, (XtPointer)0},
-  {XtNpreferredWidth, XtCPreferredWidth, XtRDimension, sizeof (Dimension),
-     offset (preferred_width), XtRImmediate, (XtPointer)0},
-  {XtNpreferredHeight, XtCPreferredHeight, XtRDimension, sizeof (Dimension),
-     offset (preferred_height), XtRImmediate, (XtPointer)0},
+  { XtNforeground, XtCForeground,
+    XtRPixel, sizeof (Pixel),
+    offset(foreground_pixel), XtRString, (XtPointer) "Black" },
+  { XtNbackground, XtCBackground,
+    XtRPixel, sizeof (Pixel),
+    offset(background_pixel), XtRString, (XtPointer) "Gray80" },
+  { XtNcursorColor, XtCForeground,
+    XtRPixel, sizeof (Pixel),
+    offset(cursor_color), XtRString, (XtPointer) "XtDefaultForeground" },
+  { XtNbarCursor, XtCBarCursor,
+    XtRBoolean, sizeof (Boolean),
+    offset (bar_cursor), XtRImmediate, (XtPointer)0 },
+  { XtNvisualBell, XtCVisualBell,
+    XtRBoolean, sizeof (Boolean),
+    offset (visual_bell), XtRImmediate, (XtPointer)0 },
+  { XtNbellVolume, XtCBellVolume,
+    XtRInt, sizeof (int),
+    offset (bell_volume), XtRImmediate, (XtPointer)0 },
+  { XtNuseBackingStore, XtCUseBackingStore,
+    XtRBoolean, sizeof (Boolean),
+    offset (use_backing_store), XtRImmediate, (XtPointer)0 },
+  { XtNpreferredWidth, XtCPreferredWidth,
+    XtRDimension, sizeof (Dimension),
+    offset (preferred_width), XtRImmediate, (XtPointer)0 },
+  { XtNpreferredHeight, XtCPreferredHeight,
+    XtRDimension, sizeof (Dimension),
+    offset (preferred_height), XtRImmediate, (XtPointer)0 },
 };
 
 #undef offset
@@ -191,7 +222,7 @@ EmacsFrameClassRec emacsFrameClassRec = {
     /* superclass		*/	&widgetClassRec,
 #endif
     /* class_name		*/	"EmacsFrame",
-    /* widget_size		*/	sizeof(EmacsFrameRec),
+    /* widget_size		*/	sizeof (EmacsFrameRec),
     /* class_initialize		*/	EmacsFrameClassInitialize,
     /* class_part_initialize	*/	0,
     /* class_inited		*/	FALSE,
@@ -201,7 +232,7 @@ EmacsFrameClassRec emacsFrameClassRec = {
     /* actions			*/	emacsFrameActionsTable,
     /* num_actions		*/	XtNumber (emacsFrameActionsTable),
     /* resources		*/	resources,
-    /* resource_count		*/	XtNumber(resources),
+    /* resource_count		*/	XtNumber (resources),
     /* xrm_class		*/	NULLQUARK,
     /* compress_motion		*/	TRUE,
     /* compress_exposure	*/	TRUE,
@@ -549,7 +580,7 @@ EmacsFrameQueryGeometry (Widget widget, XtWidgetGeometry *request,
 }
 
 /* Xt string-to-scrollbar-placement converter */
-/* ### Convert this to a `new-style' converter (See XtAddTypeConverter) */
+/* #### Convert this to a `new-style' converter (See XtAddTypeConverter) */
 
 /* This variable cannot be a stack variable. */
 static unsigned char cvt_string_scrollbar_placement;
