@@ -71,7 +71,7 @@ int signal_event_pipe_initialized;
 int fake_event_occurred;
 
 int
-read_event_from_tty_or_stream_desc (struct Lisp_Event *event,
+read_event_from_tty_or_stream_desc (Lisp_Event *event,
 				    struct console *con, int fd)
 {
   unsigned char ch;
@@ -174,7 +174,7 @@ event_stream_unixoid_unselect_console (struct console *con)
 }
 
 static int
-get_process_infd (struct Lisp_Process *p)
+get_process_infd (Lisp_Process *p)
 {
   Lisp_Object instr, outstr;
   get_process_streams (p, &instr, &outstr);
@@ -183,7 +183,7 @@ get_process_infd (struct Lisp_Process *p)
 }
 
 int
-event_stream_unixoid_select_process (struct Lisp_Process *proc)
+event_stream_unixoid_select_process (Lisp_Process *proc)
 {
   int infd = get_process_infd (proc);
 
@@ -194,7 +194,7 @@ event_stream_unixoid_select_process (struct Lisp_Process *proc)
 }
 
 int
-event_stream_unixoid_unselect_process (struct Lisp_Process *proc)
+event_stream_unixoid_unselect_process (Lisp_Process *proc)
 {
   int infd = get_process_infd (proc);
 
