@@ -659,7 +659,7 @@ x_set_frame_text_value (struct frame *f, Bufbyte *value,
   for (ptr = value; *ptr; ptr++)
     if (!BYTE_ASCII_P (*ptr))
       {
-        CONST char * tmp;
+        const char * tmp;
         encoding = DEVICE_XATOM_COMPOUND_TEXT (XDEVICE (FRAME_DEVICE (f)));
 	TO_EXTERNAL_FORMAT (C_STRING, value,
 			    C_STRING_ALLOCA, tmp,
@@ -760,7 +760,7 @@ x_set_frame_properties (struct frame *f, Lisp_Object plist)
 
       if (STRINGP (prop))
 	{
-	  CONST char *extprop;
+	  const char *extprop;
 
 	  if (XSTRING_LENGTH (prop) == 0)
 	    continue;
@@ -770,7 +770,7 @@ x_set_frame_properties (struct frame *f, Lisp_Object plist)
 			      Qctext);
 	  if (STRINGP (val))
 	    {
-	      CONST Extbyte *extval;
+	      const Extbyte *extval;
 	      Extcount extvallen;
 
 	      TO_EXTERNAL_FORMAT (LISP_STRING, val,
@@ -1191,7 +1191,7 @@ WARNING: can only handle plain/text and file: transfers!
 		  Ctext=NULL;
 		  break;
 		}
-	      strcpy (Ctext+pos, (CONST char *)XSTRING_DATA (XCAR (item)));
+	      strcpy (Ctext+pos, (const char *)XSTRING_DATA (XCAR (item)));
 	      pos += XSTRING_LENGTH (XCAR (item)) + 1;
 	      item = XCDR (item);
 	    }
@@ -1367,7 +1367,7 @@ The type defaults to DndText (4).
 		}
 	      len = XSTRING_LENGTH (XCAR (run)) + 1;
 	      dnd_data = (char *) xrealloc (dnd_data, dnd_len + len);
-	      strcpy (dnd_data + dnd_len - 1, (CONST char *)XSTRING_DATA (XCAR (run)));
+	      strcpy (dnd_data + dnd_len - 1, (const char *)XSTRING_DATA (XCAR (run)));
 	      dnd_len += len;
 	      run = XCDR (run);
 	    }
@@ -1861,7 +1861,7 @@ x_create_widgets (struct frame *f, Lisp_Object lisp_window_id,
 #ifdef EXTERNAL_WIDGET
   Window window_id = 0;
 #endif
-  CONST char *name;
+  const char *name;
   Arg al [25];
   int ac = 0;
   Widget text, container, shell;
