@@ -24,11 +24,6 @@ Boston, MA 02111-1307, USA.  */
    operating system this machine is likely to run.
    USUAL-OPSYS="usg5-3"  */
 
-/* Define WORD_MACHINE if addresses and such have
- * to be corrected before they can be used as byte counts.  */
-
-/* #define WORD_MACHINE */
-
 /* Now define a symbol for the cpu type, if your compiler
    does not define it automatically:
    Ones defined so far include vax, m68000, ns16000, pyramid,
@@ -42,14 +37,6 @@ Boston, MA 02111-1307, USA.  */
    does not define it automatically.  */
 
 
-/* Define EXPLICIT_SIGN_EXTEND if XINT must explicitly sign-extend
-   the bit field into an int.  In other words, if bit fields
-   are always unsigned.
-
-   If you use NO_UNION_TYPE, this flag does not matter.  */
-
-/* #define EXPLICIT_SIGN_EXTEND */
-
 /* Data type of load average, as read out of kmem.  */
 /* No load average on Motorola machines. */
 /* #define LOAD_AVE_TYPE double */
@@ -127,8 +114,6 @@ Boston, MA 02111-1307, USA.  */
 #define LIBS_SYSTEM "-lbsd -lg"
 #endif /* USG5_4 */
 
-/* #define NO_TERMIO */ /* mrb */
-
 #define NO_SIOCTL_H
 
 /* XEmacs change -- removed crap about random and bstring */
