@@ -2,8 +2,8 @@
 emacs_is_beta=t
 emacs_major_version=21
 emacs_minor_version=2
-emacs_beta_version=30
-xemacs_codename="Hygeia"
+emacs_beta_version=31
+xemacs_codename="Iris"
 infodock_major_version=4
 infodock_minor_version=0
 infodock_build_version=8
